@@ -1,3 +1,4 @@
+from collections import OrderedDict
 from logging import info
 from abc import abstractmethod
 from mfcloud.container import PrebuiltImageBuilder, DockerfileImageBuilder
@@ -27,6 +28,42 @@ class UnknownServiceError(Exception):
     pass
 
 
+class OrderedDictYAMLLoader(yaml.Loader):
+    """
+    A YAML loader that loads mappings into ordered dictionaries.
+    """
+
+    def __init__(self, *args, **kwargs):
+        yaml.Loader.__init__(self, *args, **kwargs)
+
+        self.add_constructor(u'tag:yaml.org,2002:map', type(self).construct_yaml_map)
+        self.add_constructor(u'tag:yaml.org,2002:omap', type(self).construct_yaml_map)
+
+    def construct_yaml_map(self, node):
+        data = OrderedDict()
+        yield data
+        value = self.construct_mapping(node)
+        data.update(value)
+
+    def construct_mapping(self, node, deep=False):
+        if isinstance(node, yaml.MappingNode):
+            self.flatten_mapping(node)
+        else:
+            raise yaml.constructor.ConstructorError(None, None,
+                'expected a mapping node, but found %s' % node.id, node.start_mark)
+
+        mapping = OrderedDict()
+        for key_node, value_node in node.value:
+            key = self.construct_object(key_node, deep=deep)
+            try:
+                hash(key)
+            except TypeError, exc:
+                raise yaml.constructor.ConstructorError('while constructing a mapping',
+                    node.start_mark, 'found unacceptable key (%s)' % exc, key_node.start_mark)
+            value = self.construct_object(value_node, deep=deep)
+            mapping[key] = value
+        return mapping
+
 class YamlConfig(IConfig):
 
     def __init__(self, file=None, source=None, app_name=None):
@@ -43,7 +80,7 @@ class YamlConfig(IConfig):
             self._file = None
 
         self.app_name = app_name
-        self.services = {}
+        self.services = OrderedDict()
 
     def get_services(self):
         """
@@ -65,11 +102,13 @@ class YamlConfig(IConfig):
         try:
             if not self._file is None:
                 with open(self._file) as f:
-                    cfg = yaml.load(f)
+                    cfg = yaml.load(f, OrderedDictYAMLLoader)
+
+                    print cfg
 
                 path = dirname(self._file)
             else:
-                cfg = yaml.load(self._source)
+                cfg = yaml.load(self._source, OrderedDictYAMLLoader)
                 path = None
 
             self.validate(config=cfg)
